@@ -1,5 +1,5 @@
-"PlotTessellation" <-
-function(coordinates,path.mcmc,printit=FALSE,path=NULL)
+`PlotTessellation` <-
+function(coordinates,path.mcmc,printit=FALSE,path)
   {
     coordinates <- as.matrix(coordinates)
       
