@@ -1,9 +1,10 @@
-"PosteriorMode" <-
+`PosteriorMode` <-
 function(coordinates,path.mcmc,write=FALSE,plotit=TRUE,
-                          printit=FALSE,file=NULL,main.title=NULL)
+                          printit=FALSE,file,main.title="")
   {
     coordinates <- as.matrix(coordinates)
       
+
                                         # get informations about the MCMC run 
     fileparam <- paste(path.mcmc,"parameters.txt",sep="")
     param <- as.matrix(read.table(fileparam))
